@@ -99,7 +99,7 @@ class ArtellaToolset(toolset.ToolsetWidget, object):
 
         bug_icon = tpDcc.ResourcesMgr().icon('bug')
 
-        self._bug_btn = buttons.BaseMenuButton()
+        self._bug_btn = buttons.BaseMenuButton(parent=self)
         self._bug_btn.setFixedWidth(22)
         self._bug_btn.setFixedHeight(22)
         self._bug_btn.set_icon(bug_icon, size=12, color_offset=40)
